@@ -390,9 +390,9 @@ mod tests {
 
   #[test]
   fn test_is_built_in_date_time_function_name() {
-    assert_eq!(true, is_built_in_date_time_function_name("date"));
-    assert_eq!(true, is_built_in_date_time_function_name("time"));
-    assert_eq!(true, is_built_in_date_time_function_name("date and time"));
-    assert_eq!(true, is_built_in_date_time_function_name("duration"));
+    assert!(is_built_in_date_time_function_name("date"));
+    assert!(is_built_in_date_time_function_name("time"));
+    assert!(is_built_in_date_time_function_name("date and time"));
+    assert!(is_built_in_date_time_function_name("duration"));
   }
 }
