@@ -332,13 +332,13 @@ mod tests {
     let mut ctx_a: FeelContext = Default::default();
     ctx_a.set_entry(&name_a, Value::Number(10.0));
     assert_eq!("{a:10}", ctx_a.feelify());
-    assert_eq!(true, ctx_a.contains_entry(&name_a));
-    assert_eq!(true, ctx_a.contains_entries(&qname_a));
-    assert_eq!(false, ctx_a.contains_entry(&name_a_b));
-    assert_eq!(false, ctx_a.contains_entries(&qname_a_b));
-    assert_eq!(false, ctx_a.contains_entry(&name_a_b_c));
-    assert_eq!(false, ctx_a.contains_entries(&qname_a_b_c));
-    assert_eq!(true, ctx_a.flatten_keys().contains("a"));
+    assert!(ctx_a.contains_entry(&name_a));
+    assert!(ctx_a.contains_entries(&qname_a));
+    assert!(!ctx_a.contains_entry(&name_a_b));
+    assert!(!ctx_a.contains_entries(&qname_a_b));
+    assert!(!ctx_a.contains_entry(&name_a_b_c));
+    assert!(!ctx_a.contains_entries(&qname_a_b_c));
+    assert!(ctx_a.flatten_keys().contains("a"));
     assert_eq!("10", ctx_a.get_entry(&name_a).unwrap().feelify().as_str());
   }
 
@@ -356,23 +356,23 @@ mod tests {
     let mut ctx_b: FeelContext = Default::default();
     ctx_b.set_entry(&name_married, Value::Boolean(true));
     assert_eq!("{married:true}", ctx_b.feelify());
-    assert_eq!(true, ctx_b.contains_entry(&name_married));
-    assert_eq!(true, ctx_b.contains_entries(&qname_married));
+    assert!(ctx_b.contains_entry(&name_married));
+    assert!(ctx_b.contains_entries(&qname_married));
     let mut ctx_a: FeelContext = Default::default();
     ctx_a.set_entry(&name_age, Value::Number(49.0));
     ctx_a.set_entry(&name_x_y, Value::Boolean(true));
     ctx_a.set_entry(&name_b, ctx_b.into());
     assert_eq!("{age:49,b:{married:true},x y:true}", ctx_a.feelify());
-    assert_eq!(true, ctx_a.contains_entry(&name_age));
-    assert_eq!(true, ctx_a.contains_entry(&name_b));
-    assert_eq!(true, ctx_a.contains_entry(&name_x_y));
-    assert_eq!(true, ctx_a.contains_entries(&qname_age));
-    assert_eq!(true, ctx_a.contains_entries(&qname_b));
-    assert_eq!(true, ctx_a.contains_entries(&qname_b_married));
-    assert_eq!(false, ctx_a.contains_entries(&qname_b_married_age));
-    assert_eq!(true, ctx_a.flatten_keys().contains("age"));
-    assert_eq!(true, ctx_a.flatten_keys().contains("b"));
-    assert_eq!(true, ctx_a.flatten_keys().contains("b . married"));
+    assert!(ctx_a.contains_entry(&name_age));
+    assert!(ctx_a.contains_entry(&name_b));
+    assert!(ctx_a.contains_entry(&name_x_y));
+    assert!(ctx_a.contains_entries(&qname_age));
+    assert!(ctx_a.contains_entries(&qname_b));
+    assert!(ctx_a.contains_entries(&qname_b_married));
+    assert!(!ctx_a.contains_entries(&qname_b_married_age));
+    assert!(ctx_a.flatten_keys().contains("age"));
+    assert!(ctx_a.flatten_keys().contains("b"));
+    assert!(ctx_a.flatten_keys().contains("b . married"));
     assert_eq!("49", ctx_a.get_entry(&name_age).unwrap().feelify().as_str());
     assert_eq!("{married:true}", ctx_a.get_entry(&name_b).unwrap().feelify().as_str());
   }
@@ -387,24 +387,24 @@ mod tests {
     let mut ctx_c: FeelContext = Default::default();
     ctx_c.set_entry(&name_car, Value::String("opel".to_string()));
     assert_eq!(r#"{car:"opel"}"#, ctx_c.feelify());
-    assert_eq!(true, ctx_c.contains_entry(&name_car));
+    assert!(ctx_c.contains_entry(&name_car));
     let mut ctx_b: FeelContext = Default::default();
     ctx_b.set_entry(&name_married, Value::Boolean(true));
     ctx_b.set_entry(&name_c, ctx_c.into());
     assert_eq!(r#"{c:{car:"opel"},married:true}"#, ctx_b.feelify());
-    assert_eq!(true, ctx_b.contains_entry(&name_married));
-    assert_eq!(true, ctx_b.contains_entry(&name_c));
+    assert!(ctx_b.contains_entry(&name_married));
+    assert!(ctx_b.contains_entry(&name_c));
     let mut ctx_a: FeelContext = Default::default();
     ctx_a.set_entry(&name_age, Value::Number(49.0));
     ctx_a.set_entry(&name_b, ctx_b.into());
     assert_eq!(r#"{age:49,b:{c:{car:"opel"},married:true}}"#, ctx_a.feelify());
-    assert_eq!(true, ctx_a.contains_entry(&name_age));
-    assert_eq!(true, ctx_a.contains_entry(&name_b));
-    assert_eq!(true, ctx_a.flatten_keys().contains("age"));
-    assert_eq!(true, ctx_a.flatten_keys().contains("b"));
-    assert_eq!(true, ctx_a.flatten_keys().contains("b . c"));
-    assert_eq!(true, ctx_a.flatten_keys().contains("b . married"));
-    assert_eq!(true, ctx_a.flatten_keys().contains("b . c . car"));
+    assert!(ctx_a.contains_entry(&name_age));
+    assert!(ctx_a.contains_entry(&name_b));
+    assert!(ctx_a.flatten_keys().contains("age"));
+    assert!(ctx_a.flatten_keys().contains("b"));
+    assert!(ctx_a.flatten_keys().contains("b . c"));
+    assert!(ctx_a.flatten_keys().contains("b . married"));
+    assert!(ctx_a.flatten_keys().contains("b . c . car"));
   }
 
   #[test]
@@ -457,16 +457,16 @@ mod tests {
     ctx_a.set_entry(&name_b, ctx_b.into());
     assert_eq!(r#"{a:"a",b:{c:"c",d:{e:"e"}}}"#, ctx_a.feelify());
     // test searching entries
-    assert_eq!(true, ctx_a.contains_entries(&qn_a));
-    assert_eq!(true, ctx_a.contains_entries(&qn_b));
-    assert_eq!(false, ctx_a.contains_entries(&qn_c));
-    assert_eq!(false, ctx_a.contains_entries(&qn_a_b));
-    assert_eq!(false, ctx_a.contains_entries(&qn_a_c));
-    assert_eq!(true, ctx_a.contains_entries(&qn_b_c));
-    assert_eq!(false, ctx_a.contains_entries(&qn_b_e));
-    assert_eq!(true, ctx_a.contains_entries(&qn_b_d));
-    assert_eq!(false, ctx_a.contains_entries(&qn_b_d_a));
-    assert_eq!(true, ctx_a.contains_entries(&qn_b_d_e));
+    assert!(ctx_a.contains_entries(&qn_a));
+    assert!(ctx_a.contains_entries(&qn_b));
+    assert!(!ctx_a.contains_entries(&qn_c));
+    assert!(!ctx_a.contains_entries(&qn_a_b));
+    assert!(!ctx_a.contains_entries(&qn_a_c));
+    assert!(ctx_a.contains_entries(&qn_b_c));
+    assert!(!ctx_a.contains_entries(&qn_b_e));
+    assert!(ctx_a.contains_entries(&qn_b_d));
+    assert!(!ctx_a.contains_entries(&qn_b_d_a));
+    assert!(ctx_a.contains_entries(&qn_b_d_e));
   }
 
   #[test]
