@@ -164,25 +164,25 @@ mod tests {
   /// Tests whether the constructor creates a new [QualifiedName] properly.
   #[test]
   fn test_new_qualified_name() {
-    let a = Name::new(&["a", "+", "b"]);
-    let b = Name::new(&["b", "-", "c"]);
-    let c = Name::new(&["c", "/", "d"]);
-    let d = Name::new(&["d", "*", "e"]);
-    let e = Name::new(&["e", ".", "f"]);
-    let f = Name::new(&["f", "'", "g"]);
+    let name_a = Name::new(&["a", "+", "b"]);
+    let name_b = Name::new(&["b", "-", "c"]);
+    let name_c = Name::new(&["c", "/", "d"]);
+    let name_d = Name::new(&["d", "*", "e"]);
+    let name_e = Name::new(&["e", ".", "f"]);
+    let name_f = Name::new(&["f", "'", "g"]);
     let qname = QualifiedName::new(&[]);
     assert_eq!("", qname.to_string().as_str());
-    let qname = QualifiedName::new(&[&a]);
+    let qname = QualifiedName::new(&[&name_a]);
     assert_eq!("a + b", qname.to_string().as_str());
-    let qname = QualifiedName::new(&[&a, &b]);
+    let qname = QualifiedName::new(&[&name_a, &name_b]);
     assert_eq!("a + b.b - c", qname.to_string().as_str());
-    let qname = QualifiedName::new(&[&a, &b, &c]);
+    let qname = QualifiedName::new(&[&name_a, &name_b, &name_c]);
     assert_eq!("a + b.b - c.c / d", qname.to_string().as_str());
-    let qname = QualifiedName::new(&[&a, &b, &c, &d]);
+    let qname = QualifiedName::new(&[&name_a, &name_b, &name_c, &name_d]);
     assert_eq!("a + b.b - c.c / d.d * e", qname.to_string().as_str());
-    let qname = QualifiedName::new(&[&a, &b, &c, &d, &e]);
+    let qname = QualifiedName::new(&[&name_a, &name_b, &name_c, &name_d, &name_e]);
     assert_eq!("a + b.b - c.c / d.d * e.e . f", qname.to_string().as_str());
-    let qname = QualifiedName::new(&[&a, &b, &c, &d, &e, &f]);
+    let qname = QualifiedName::new(&[&name_a, &name_b, &name_c, &name_d, &name_e, &name_f]);
     assert_eq!("a + b.b - c.c / d.d * e.e . f.f ' g", qname.to_string().as_str());
   }
 }
