@@ -473,8 +473,8 @@ mod tests {
     );
     assert!(FeelDaysAndTimeDuration::new(10, 0) < FeelDaysAndTimeDuration::new(11, 0));
     assert!(FeelDaysAndTimeDuration::new(10, 1) < FeelDaysAndTimeDuration::new(10, 2));
-    assert!(!(FeelDaysAndTimeDuration::new(11, 0) < FeelDaysAndTimeDuration::new(10, 0)));
-    assert!(!(FeelDaysAndTimeDuration::new(10, 2) < FeelDaysAndTimeDuration::new(10, 1)));
+    assert!(FeelDaysAndTimeDuration::new(11, 0) >= FeelDaysAndTimeDuration::new(10, 0));
+    assert!(FeelDaysAndTimeDuration::new(10, 2) >= FeelDaysAndTimeDuration::new(10, 1));
   }
 
   #[test]
@@ -483,8 +483,8 @@ mod tests {
     assert!(FeelDaysAndTimeDuration::new(10, 0) <= FeelDaysAndTimeDuration::new(10, 0));
     assert!(FeelDaysAndTimeDuration::new(10, 0) <= FeelDaysAndTimeDuration::new(10, 1));
     assert!(FeelDaysAndTimeDuration::new(10, 1) <= FeelDaysAndTimeDuration::new(10, 1));
-    assert!(!(FeelDaysAndTimeDuration::new(11, 0) <= FeelDaysAndTimeDuration::new(10, 0)));
-    assert!(!(FeelDaysAndTimeDuration::new(10, 2) <= FeelDaysAndTimeDuration::new(10, 1)));
+    assert!(FeelDaysAndTimeDuration::new(11, 0) > FeelDaysAndTimeDuration::new(10, 0));
+    assert!(FeelDaysAndTimeDuration::new(10, 2) > FeelDaysAndTimeDuration::new(10, 1));
   }
 
   #[test]
@@ -499,8 +499,8 @@ mod tests {
     );
     assert!(FeelDaysAndTimeDuration::new(11, 0) > FeelDaysAndTimeDuration::new(10, 0));
     assert!(FeelDaysAndTimeDuration::new(10, 1) > FeelDaysAndTimeDuration::new(10, 0));
-    assert!(!(FeelDaysAndTimeDuration::new(10, 0) > FeelDaysAndTimeDuration::new(11, 0)));
-    assert!(!(FeelDaysAndTimeDuration::new(10, 1) > FeelDaysAndTimeDuration::new(10, 2)));
+    assert!(FeelDaysAndTimeDuration::new(10, 0) <= FeelDaysAndTimeDuration::new(11, 0));
+    assert!(FeelDaysAndTimeDuration::new(10, 1) <= FeelDaysAndTimeDuration::new(10, 2));
   }
 
   #[test]
@@ -509,8 +509,8 @@ mod tests {
     assert!(FeelDaysAndTimeDuration::new(10, 0) >= FeelDaysAndTimeDuration::new(10, 0));
     assert!(FeelDaysAndTimeDuration::new(10, 1) >= FeelDaysAndTimeDuration::new(10, 0));
     assert!(FeelDaysAndTimeDuration::new(10, 1) >= FeelDaysAndTimeDuration::new(10, 1));
-    assert!(!(FeelDaysAndTimeDuration::new(10, 0) >= FeelDaysAndTimeDuration::new(11, 0)));
-    assert!(!(FeelDaysAndTimeDuration::new(10, 1) >= FeelDaysAndTimeDuration::new(10, 2)));
+    assert!(FeelDaysAndTimeDuration::new(10, 0) < FeelDaysAndTimeDuration::new(11, 0));
+    assert!(FeelDaysAndTimeDuration::new(10, 1) < FeelDaysAndTimeDuration::new(10, 2));
   }
 
   #[test]
@@ -520,27 +520,27 @@ mod tests {
     let c = FeelDaysAndTimeDuration::new(94, 0);
     assert_eq!(c, a + b);
     let a = FeelDaysAndTimeDuration::new(11, 2_837);
-    let b = FeelDaysAndTimeDuration::new(83, 0_023);
+    let b = FeelDaysAndTimeDuration::new(83, 23);
     let c = FeelDaysAndTimeDuration::new(94, 2_860);
     assert_eq!(c, a + b);
     let a = FeelDaysAndTimeDuration::new(1, 999_999_999);
-    let b = FeelDaysAndTimeDuration::new(1, 000_000_002);
-    let c = FeelDaysAndTimeDuration::new(3, 000_000_001);
+    let b = FeelDaysAndTimeDuration::new(1, 2);
+    let c = FeelDaysAndTimeDuration::new(3, 1);
     assert_eq!(c, a + b);
   }
 
   #[test]
   fn test_sub_should_pass() {
     let a = FeelDaysAndTimeDuration::new(12, 0);
-    let b = FeelDaysAndTimeDuration::new(02, 0);
+    let b = FeelDaysAndTimeDuration::new(2, 0);
     let c = FeelDaysAndTimeDuration::new(10, 0);
     assert_eq!(c, a - b);
     let a = FeelDaysAndTimeDuration::new(99, 999_999_999);
     let b = FeelDaysAndTimeDuration::new(77, 888_888_888);
     let c = FeelDaysAndTimeDuration::new(22, 111_111_111);
     assert_eq!(c, a - b);
-    let a = FeelDaysAndTimeDuration::new(1, 000_000_001);
-    let b = FeelDaysAndTimeDuration::new(0, 000_000_002);
+    let a = FeelDaysAndTimeDuration::new(1, 1);
+    let b = FeelDaysAndTimeDuration::new(0, 2);
     let c = FeelDaysAndTimeDuration::new(0, 999_999_999);
     assert_eq!(c, a - b);
   }
