@@ -673,33 +673,33 @@ mod tests {
 
   #[test]
   fn test_parse_date() {
-    eq_date(2020, 09, 28, "2020-09-28");
+    eq_date(2020, 9, 28, "2020-09-28");
   }
 
   #[test]
   fn test_parse_time() {
-    eq_time_loc(18, 37, 09, "18:37:09");
-    eq_time_utc(16, 37, 09, "16:37:09z");
-    eq_time_utc(16, 37, 09, "16:37:09Z");
-    eq_time_utc(16, 37, 09, "16:37:09@Etc/UTC");
-    eq_time_utc(16, 37, 09, "18:37:09@Africa/Johannesburg");
-    eq_time_utc(16, 37, 09, "17:37:09@Europe/London");
-    eq_time_utc(17, 37, 09, "10:37:09@America/Vancouver");
-    eq_time_utc(17, 37, 09, "13:37:09@America/New_York");
-    eq_time_utc(16, 37, 09, "18:37:09@Europe/Warsaw");
+    eq_time_loc(18, 37, 9, "18:37:09");
+    eq_time_utc(16, 37, 9, "16:37:09z");
+    eq_time_utc(16, 37, 9, "16:37:09Z");
+    eq_time_utc(16, 37, 9, "16:37:09@Etc/UTC");
+    eq_time_utc(16, 37, 9, "18:37:09@Africa/Johannesburg");
+    eq_time_utc(16, 37, 9, "17:37:09@Europe/London");
+    eq_time_utc(17, 37, 9, "10:37:09@America/Vancouver");
+    eq_time_utc(17, 37, 9, "13:37:09@America/New_York");
+    eq_time_utc(16, 37, 9, "18:37:09@Europe/Warsaw");
   }
 
   #[test]
   fn test_parse_date_time() {
-    eq_date_time_loc((2020, 09, 28), (16, 37, 09), "2020-09-28T16:37:09");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T16:37:09z");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T16:37:09Z");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T16:37:09@Etc/UTC");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T18:37:09@Africa/Johannesburg");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T17:37:09@Europe/London");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T09:37:09@America/Vancouver");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T12:37:09@America/New_York");
-    eq_date_time_utc((2020, 09, 28), (16, 37, 09), "2020-09-28T18:37:09@Europe/Warsaw");
+    eq_date_time_loc((2020, 9, 28), (16, 37, 9), "2020-09-28T16:37:09");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T16:37:09z");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T16:37:09Z");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T16:37:09@Etc/UTC");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T18:37:09@Africa/Johannesburg");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T17:37:09@Europe/London");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T09:37:09@America/Vancouver");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T12:37:09@America/New_York");
+    eq_date_time_utc((2020, 9, 28), (16, 37, 9), "2020-09-28T18:37:09@Europe/Warsaw");
   }
 
   #[test]
@@ -714,41 +714,38 @@ mod tests {
 
   #[test]
   fn test_get_local_offset() {
-    assert_eq!(Some(1 * SECONDS_IN_HOUR), get_local_offset((2020, 10, 29), (09, 12, 03, 0)));
+    assert_eq!(Some(SECONDS_IN_HOUR), get_local_offset((2020, 10, 29), (9, 12, 3, 0)));
     assert_eq!(
-      get_zone_offset("Europe/Warsaw", (2020, 6, 12), (09, 12, 03, 0)),
-      get_local_offset((2020, 6, 12), (09, 12, 03, 0))
+      get_zone_offset("Europe/Warsaw", (2020, 6, 12), (9, 12, 3, 0)),
+      get_local_offset((2020, 6, 12), (9, 12, 3, 0))
     );
   }
 
   #[test]
   fn test_get_zone_offset() {
     // winter time in Warsaw, offset = +01:00
-    assert_eq!(Some(1 * SECONDS_IN_HOUR), get_zone_offset("Europe/Warsaw", (2020, 10, 29), (09, 12, 03, 0)));
+    assert_eq!(Some(SECONDS_IN_HOUR), get_zone_offset("Europe/Warsaw", (2020, 10, 29), (9, 12, 3, 0)));
     // summer time in Warsaw, offset = +02:00
-    assert_eq!(Some(2 * SECONDS_IN_HOUR), get_zone_offset("Europe/Warsaw", (2020, 06, 21), (11, 13, 49, 0)));
+    assert_eq!(Some(2 * SECONDS_IN_HOUR), get_zone_offset("Europe/Warsaw", (2020, 6, 21), (11, 13, 49, 0)));
     // time in Moscow, offset = +03:00
-    assert_eq!(Some(3 * SECONDS_IN_HOUR), get_zone_offset("Europe/Moscow", (2020, 10, 29), (09, 12, 03, 0)));
+    assert_eq!(Some(3 * SECONDS_IN_HOUR), get_zone_offset("Europe/Moscow", (2020, 10, 29), (9, 12, 3, 0)));
     // summer time in New York, offset = -04:00
-    assert_eq!(Some(-4 * SECONDS_IN_HOUR), get_zone_offset("America/New_York", (2020, 06, 28), (12, 12, 03, 0)));
+    assert_eq!(Some(-4 * SECONDS_IN_HOUR), get_zone_offset("America/New_York", (2020, 6, 28), (12, 12, 3, 0)));
     // winter time in New York, offset = -05:00
-    assert_eq!(Some(-5 * SECONDS_IN_HOUR), get_zone_offset("America/New_York", (2020, 11, 12), (18, 04, 33, 0)));
+    assert_eq!(Some(-5 * SECONDS_IN_HOUR), get_zone_offset("America/New_York", (2020, 11, 12), (18, 4, 33, 0)));
     // time in Kolkata, offset = +05:30
     assert_eq!(
       Some(5 * SECONDS_IN_HOUR + 30 * SECONDS_IN_MIN),
-      get_zone_offset("Asia/Kolkata", (2020, 11, 12), (18, 04, 33, 0))
+      get_zone_offset("Asia/Kolkata", (2020, 11, 12), (18, 4, 33, 0))
     );
     // no time change in Kolkata in summer, offset = +05:30
     assert_eq!(
       Some(5 * SECONDS_IN_HOUR + 30 * SECONDS_IN_MIN),
-      get_zone_offset("Asia/Kolkata", (2020, 06, 08), (8, 0, 0, 0))
+      get_zone_offset("Asia/Kolkata", (2020, 6, 8), (8, 0, 0, 0))
     );
     // time in Honolulu, offset = -10:00
-    assert_eq!(
-      Some(-10 * SECONDS_IN_HOUR),
-      get_zone_offset("Pacific/Honolulu", (2020, 11, 12), (18, 04, 33, 0))
-    );
+    assert_eq!(Some(-10 * SECONDS_IN_HOUR), get_zone_offset("Pacific/Honolulu", (2020, 11, 12), (18, 4, 33, 0)));
     // no time change in Honolulu in summer, offset = -10:00
-    assert_eq!(Some(-10 * SECONDS_IN_HOUR), get_zone_offset("Pacific/Honolulu", (2020, 06, 08), (8, 0, 0, 0)));
+    assert_eq!(Some(-10 * SECONDS_IN_HOUR), get_zone_offset("Pacific/Honolulu", (2020, 6, 8), (8, 0, 0, 0)));
   }
 }
