@@ -14,7 +14,7 @@
 
 //! `FEEL` years and months durations.
 
-use {self::errors::*, dmntk_common::errors::DmntkError, regex::Regex, std::convert::TryFrom};
+use {self::errors::*, dmntk_common::DmntkError, regex::Regex, std::convert::TryFrom};
 
 /// Regular expression pattern for parsing years and months duration.
 const REGEX_YEARS_AND_MONTHS: &str = r#"^(?P<sign>-)?P((?P<years>[0-9]+)Y)?((?P<months>[0-9]+)M)?$"#;
@@ -124,7 +124,7 @@ impl TryFrom<&str> for FeelYearsAndMonthsDuration {
 
 /// Definitions of years and months duration errors.
 pub mod errors {
-  use dmntk_common::errors::DmntkError;
+  use dmntk_common::DmntkError;
 
   /// Years and months duration errors.
   #[derive(Debug, PartialEq)]
