@@ -16,22 +16,17 @@
 
 //! Definitions of `FEEL` types.
 
-use dmntk_common::Stringify;
 use {
+  self::errors::*,
   crate::{
     context::FeelContext,
     names::Name,
     values::{Value, Values, VALUE_NULL},
   },
-  dmntk_common::DmntkError,
+  dmntk_common::{DmntkError, Result, Stringify},
   std::{collections::BTreeMap, str::FromStr},
 };
 
-// pub type OptFeelType = Option<FeelType>;
-
-// pub const FEEL_TYPE_ANY: FeelType = FeelType::Any;
-// pub const FEEL_TYPE_NULL: FeelType = FeelType::Null;
-
 pub const FEEL_TYPE_NAME_ANY: &str = "Any";
 const FEEL_TYPE_NAME_BOOLEAN: &str = "boolean";
 const FEEL_TYPE_NAME_DATE: &str = "date";
@@ -47,31 +42,31 @@ const FEEL_TYPE_NAME_YEARS_AND_MONTHS_DURATION: &str = "years and months duratio
 pub enum FeelType {
   /// Type representing any valid `FEEL` type.
   Any,
-  /// Type of `boolean` value.
+  /// Type representing a `boolean` value.
   Boolean,
-  /// Type of `context` values.
+  /// Type representing `context` values.
   Context(BTreeMap<Name, FeelType>),
-  /// Type of `date` value.
+  /// Type representing `date` value.
   Date,
-  /// Type of `date and time` value.
+  /// Type representing `date and time` value.
   DateTime,
-  /// Type of `days and time duration` value.
+  /// Type representing `days and time duration` value.
   DaysAndTimeDuration,
-  /// Type of `function` values.
+  /// Type representing `function` values.
   Function(Vec<FeelType>, Box<FeelType>),
-  /// Type of `list` values.
+  /// Type representing `list` values.
   List(Box<FeelType>),
-  /// Type of `null` value.
+  /// Type representing `null` value.
   Null,
-  /// Type of `number` value.
+  /// Type representing `number` value.
   Number,
-  /// Type of `range` values.
+  /// Type representing `range` values.
   Range(Box<FeelType>),
-  /// Type of `string` value.
+  /// Type representing `string` value.
   String,
-  /// Type of `time` value.
+  /// Type representing `time` value.
   Time,
-  /// Type of `years and months duration` value.
+  /// Type representing `years and months duration` value.
   YearsAndMonthsDuration,
 }
 
@@ -112,7 +107,7 @@ impl FromStr for FeelType {
       FEEL_TYPE_NAME_STRING => Ok(Self::String),
       FEEL_TYPE_NAME_TIME => Ok(Self::Time),
       FEEL_TYPE_NAME_YEARS_AND_MONTHS_DURATION => Ok(Self::YearsAndMonthsDuration),
-      _ => Err(self::errors::unknown_type_name(s)),
+      _ => Err(invalid_feel_type_name(s)),
     }
   }
 }
@@ -135,100 +130,95 @@ pub fn is_built_in_type_name(name: &str) -> bool {
 }
 
 impl FeelType {
-  /// Derives a new value from provided value checking the types.
-  pub fn derive(&self, value: &Value) -> Option<Value> {
+  /// Returns a new value cloned from provided value, and retrieved with type checking.
+  pub fn retrieve_value_with_type_checking(&self, value: &Value) -> Result<Value> {
     if let Value::Null(_) = value {
       // `null` value is conformant with all types
-      return Some(VALUE_NULL);
+      return Ok(VALUE_NULL);
     }
     match self {
       FeelType::Any => {
-        return Some(value.clone());
+        return Ok(value.clone());
       }
       FeelType::Boolean => {
         if let Value::Boolean(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::Context(entries) => {
         if let Value::Context(context) = value {
           let mut result = FeelContext::default();
-          for (name, type_node) in entries {
+          for (name, entry_type) in entries {
             if let Some(entry_value) = context.get_entry(name) {
-              if let Some(evaluated_value) = type_node.derive(entry_value) {
-                result.set_entry(name, evaluated_value);
-              }
+              result.set_entry(name, entry_type.retrieve_value_with_type_checking(entry_value)?);
             }
           }
-          return Some(Value::Context(result));
+          return Ok(Value::Context(result));
         }
       }
       FeelType::Date => {
         if let Value::Date(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::DateTime => {
         if let Value::DateTime(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::DaysAndTimeDuration => {
         if let Value::DaysAndTimeDuration(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::Function(_, _) => {
         if let Value::FunctionDefinition(_, _) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
-      FeelType::List(typ) => {
+      FeelType::List(items_type) => {
         if let Value::List(items) = value {
           let mut result = vec![];
           for item in items.to_vec() {
-            if let Some(evaluated_value) = typ.derive(&item) {
-              result.push(evaluated_value);
-            }
+            result.push(items_type.retrieve_value_with_type_checking(&item)?);
           }
-          return Some(Value::List(Values::new(result)));
+          return Ok(Value::List(Values::new(result)));
         }
       }
       FeelType::Null => {
         if let Value::Null(_) = value {
-          return Some(VALUE_NULL);
+          return Ok(VALUE_NULL);
         }
       }
       FeelType::Number => {
         if let Value::Number(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::Range(_) => {
         if let Value::Range(_, _, _, _) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::String => {
         if let Value::String(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::Time => {
         if let Value::Time(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
       FeelType::YearsAndMonthsDuration => {
         if let Value::YearsAndMonthsDuration(_) = value {
-          return Some(value.clone());
+          return Ok(value.clone());
         }
       }
     }
-    None
+    Err(invalid_value_for_retrieving_using_feel_type(&self.stringify(), &value.stringify()))
   }
-
-  /// Returns `true` when this type is a simple `FEEL` build-in type.
+  /// Returns `true` when this type is a simple `FEEL` type.
   pub fn is_simple_built_in_type(&self) -> bool {
     matches!(
       self,
@@ -244,27 +234,23 @@ impl FeelType {
         | Self::YearsAndMonthsDuration
     )
   }
-
-  /// Creates a list type with specified item's type.
-  pub fn list(item_type: &FeelType) -> FeelType {
-    FeelType::List(Box::new(item_type.clone()))
+  /// Creates a `list` type with specified items' type.
+  pub fn list(items_type: &FeelType) -> FeelType {
+    FeelType::List(Box::new(items_type.clone()))
   }
-
-  /// Creates a range type with specified element's type.
-  pub fn range(element_type: &FeelType) -> FeelType {
-    FeelType::Range(Box::new(element_type.clone()))
+  /// Creates a `range` type with specified elements' type.
+  pub fn range(elements_type: &FeelType) -> FeelType {
+    FeelType::Range(Box::new(elements_type.clone()))
   }
-
-  /// Creates a context type with specified entries' types.
-  pub fn context(entry_types: &[(&Name, &FeelType)]) -> FeelType {
-    FeelType::Context(entry_types.iter().map(|(name, typ)| ((*name).clone(), (*typ).clone())).collect())
+  /// Creates a `context` type with specified entries' types.
+  pub fn context(entries_types: &[(&Name, &FeelType)]) -> FeelType {
+    FeelType::Context(entries_types.iter().map(|(name, typ)| ((*name).clone(), (*typ).clone())).collect())
   }
-
-  /// Creates a function type with specified parameter types and return type.
+  /// Creates a `function` type with specified parameter types and return type.
   pub fn function(parameter_types: &[FeelType], result_type: &FeelType) -> FeelType {
     FeelType::Function(parameter_types.iter().map(|typ| (*typ).clone()).collect(), Box::new((*result_type).clone()))
   }
-
+  ///
   pub fn zip(&self, other: &FeelType) -> FeelType {
     if self == other {
       self.clone()
@@ -393,46 +379,77 @@ impl FeelType {
   }
 }
 
-/// Definitions of errors raised in `types` module.
-pub mod errors {
+/// Definitions of errors raised by `types` module.
+mod errors {
   use dmntk_common::DmntkError;
 
-  /// Type errors.
+  /// Definition of errors raised in `types` module.
   #[derive(Debug, PartialEq)]
-  pub enum TypeError {
-    /// Raised when the specified name is not a type name.
-    UnknownTypeName(String),
+  pub enum TypesError {
+    /// Error raised when the specified text is not a valid `FEEL` type name.
+    InvalidFeelTypeName(String),
+    /// Error raised when the specified value is not valid for retrieving with type checking with `FEEL` type.
+    InvalidValueForRetrievingUsingFeelType(String, String),
   }
 
-  impl From<TypeError> for DmntkError {
-    /// Converts [TypeError] into [DmntkError].
-    fn from(e: TypeError) -> Self {
+  impl From<TypesError> for DmntkError {
+    /// Converts [TypesError] into [DmntkError].
+    fn from(e: TypesError) -> Self {
       DmntkError::new("TypesError", &e.to_string())
     }
   }
 
-  impl std::fmt::Display for TypeError {
-    /// Implements [Display] trait for [TypeError]s.
+  impl std::fmt::Display for TypesError {
+    /// Implements [Display] trait for [TypesError].
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
       match self {
-        TypeError::UnknownTypeName(name) => write!(f, "unknown type name: {}", name),
+        TypesError::InvalidFeelTypeName(s) => {
+          write!(f, "invalid FEEL type name: {}", s)
+        }
+        TypesError::InvalidValueForRetrievingUsingFeelType(s1, s2) => {
+          write!(f, "invalid value for retrieving with type check, type = `{}`, value = `{}`", s1, s2)
+        }
       }
     }
   }
 
-  /// Creates an [UnknownTypeName](TypeError::UnknownTypeName) error.
-  pub fn unknown_type_name(name: &str) -> DmntkError {
-    TypeError::UnknownTypeName(name.to_string()).into()
+  /// Creates an [InvalidFeelTypeName](TypesError::InvalidFeelTypeName) error.
+  pub fn invalid_feel_type_name(s: &str) -> DmntkError {
+    TypesError::InvalidFeelTypeName(s.to_owned()).into()
+  }
+
+  /// Creates an [InvalidValueForRetrievingWithTypeCheck](TypesError::InvalidValueForRetrievingWithTypeCheck) error.
+  pub fn invalid_value_for_retrieving_using_feel_type(s1: &str, s2: &str) -> DmntkError {
+    TypesError::InvalidValueForRetrievingUsingFeelType(s1.to_owned(), s2.to_owned()).into()
   }
 }
 
 #[cfg(test)]
 mod tests {
-  use super::{
-    is_built_in_type_name,
-    FeelType::{self, Any, Number},
+  use crate::{
+    names::Name,
+    types::{
+      is_built_in_type_name,
+      FeelType::{self, Any, Number},
+    },
+    values::Value,
   };
-  use crate::names::Name;
+
+  #[test]
+  fn test_retrieve_value_with_type_checking() {
+    let t_any = FeelType::Any;
+    let t_boolean = FeelType::Boolean;
+    let v_null = Value::Null(None);
+    let v_boolean = Value::Boolean(true);
+    let v_string = Value::String("hello".to_owned());
+    assert_eq!(Value::Null(None), t_any.retrieve_value_with_type_checking(&v_null).unwrap());
+    assert_eq!(Value::Boolean(true), t_any.retrieve_value_with_type_checking(&v_boolean).unwrap());
+    assert!(t_boolean.retrieve_value_with_type_checking(&v_string).is_err());
+    assert_eq!(
+      r#"TypesError: invalid value for retrieving with type check, type = `boolean`, value = `"hello"`"#,
+      format!("{}", t_boolean.retrieve_value_with_type_checking(&v_string).err().unwrap()).as_str()
+    );
+  }
 
   #[test]
   fn test_type_equivalence() {
